﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Linq;
using System.Text;
using System.Windows.Forms;

namespace QQGroupControLlibraries
{
    [Docking(DockingBehavior.Ask)]
    [ToolboxItem(false)]
    public partial class QQGroupItem : UserControl
    {
        public QQGroupItem()
        {
            InitializeComponent();
        }

        /// <summary>
        ///     初始化时设置分组名称
        /// </summary>
        public QQGroupItem(string groupName)
        {
            InitializeComponent();
            this.Text = groupName;
        }

        /// <summary>
        ///     初始化时设置分组名称
        /// </summary>
        public QQGroupItem(string groupName, Image normal, Image focus, Image click)
        {
            InitializeComponent();
            this.Text = groupName;
            this.button.BackgroundImage = normal;

            this.button.MouseEnter += delegate(object sender, EventArgs e)
            {
                this.button.BackgroundImage = focus;
            };

            this.button.MouseLeave += delegate(object sender, EventArgs e)
            {
                this.button.BackgroundImage = normal;
            };

            this.button.MouseDown += delegate(object sender, MouseEventArgs e)
            {
                this.button.BackgroundImage = click;
            };

        }

        /// <summary>
        ///     组按钮
        /// </summary>
        [Browsable(true)]
        [Description("组按钮")]
        public Button GroupButton { get { return this.button; } set { this.button = value; } }

        /// <summary>
        ///     组名称
        /// </summary>
        [Browsable(true)]
        [Description("组名称")]
        public override string Text
        {
            get
            {
                return this.button.Text;
            }
            set
            {
                this.button.Text = value;
            }
        }

        public ListView ListView { get { return this.listView1; } set { this.listView1 = value; } }

        public ListView.ListViewItemCollection Items { get { return this.listView1.Items; } }

        /// <summary>
        ///     是否默认展开List
        /// </summary>
        [Description("是否默认展开")]
        [DefaultValue(true)]
        public bool ShowList {
            get {
                return this.listView1.Visible;
            }
            set {
                if (!value)
                {
                    //如果为隐藏
                    this.GroupHeigth = this.Height;
                    if (this.Height > this.button.Height) this.Height = this.button.Height;
                }
                else
                {
                    //MessageBox.Show(this.GroupHeigth.ToString());
                            
                    //如果为显示
                    this.Height = this.GroupHeigth;
                }
                this.listView1.Visible = value;
            }
        }

        [Description("分组展开时的分组高度")]
        public int GroupHeigth { get; set; }

        /// <summary>
        ///     为解决事件执行顺序而诞生的小姑娘
        /// </summary>
        private bool showList { get; set; }

        #region 事件
        /// <summary>
        ///     分组按钮被点击
        /// </summary>
        private void button_Click(object sender, EventArgs e)
        {
            showList = !this.showList;
            this.ShowList = !this.ShowList;
        }

        /// <summary>
        ///     窗体改变时
        /// </summary>
        private void QQGroupItem_Resize(object sender, EventArgs e)
        {
            if (this.showList)
            {
                if(this.Height != this.button.Height)
                //如果不是隐藏情况下
                this.GroupHeigth = this.Height;
            }
        }

        /// <summary>
        ///     加载时
        /// </summary>
        private void QQGroupItem_Load(object sender, EventArgs e)
        {
            this.Dock = DockStyle.Top;
            if (this.Height != this.button.Height)
            {
                this.GroupHeigth = this.Height;
            }
            this.showList = this.ShowList;
        }
        #endregion
    }
}
